@@ -35,10 +35,12 @@ import errno
 import fcntl
 import grp
 import hashlib
+import hubzero.config.webconfig
 import MySQLdb
 import os
 import pprint
 import pwd
+import random
 import re
 import smtplib
 import stat
@@ -391,40 +393,44 @@ def extractMessageFromEmail(emailText):
 def getAttachments(emailText):
 	msg = email.message_from_string(emailText)
 	attachments = _getAttachments(msg)
+
 	return attachments
 
 
 def _getAttachments(msg_part):
+	"""return a list of lists. Each sublist in the list is a 2 element list with a filename followed by the 
+	text of the attachment
+	"""
 
-	acceptable = ['text/plain', 'image/png','image/jpg','image/jpeg','image/gif','image/tiff','application/pdf','application/msword','application/vnd.openxmlformats-officedocument.wordprocessingml.document']
+	acceptable = ['text/plain', 
+		'image/png',
+		'image/jpg',
+		'image/jpeg',
+		'image/gif',
+		'image/tiff',
+		'application/pdf',
+		'application/msword',
+		'application/vnd.openxmlformats-officedocument.wordprocessingml.document']
 
-	if msg_part.is_multipart():
-		# the base email returned by the python email parsing utils is a multipart 
-		# message that needs parsing. If multipart/alternative is set on the part, 
-		# that means this message part has multiple representaitons. This is generally
-		# used for including html *and* text versions of email and letting email clients
-		# decide which to display. It's possible for a given message part, to include
-		# a gif and a JPEG, but I'm assuming most email clients, when attaching a file
-		# to an email generally don't transcode the attachments, but just send them
-		if "multipart/alternative" not in msg_part.get_content_type():
-			attachments = []
-			for m in msg_part.get_payload():
-				a = _getAttachments(m)
-				if a:
-					attachments.append(a)
-			return attachments
-		else:
-			return None
-	else:
-		attach = []
-		attachedFilename = msg_part.get_filename()
-		# some attachments might not have associated filenames
-		if not attachedFilename:
-			attachedFilename = "attachment"
+	attachments = []
 
-		attach.append( [attachedFilename, msg_part.get_payload(decode=True)] )
+	# i.e if message is not multipart, msg_part will simply return a string, no attachments
+	# in this case
+	if not msg_part.is_multipart():
+		return attachments
 
-		return attach
+	for m in msg_part.get_payload():
+
+		# for some reason some clients store versions of the message
+		# as attachments, they have no filename. We don't want them
+		filename = m.get_filename()
+
+		if not filename:
+			continue
+	
+		attachments.append([filename, m.get_content_type(), m.get_payload(decode=True)])
+
+	return attachments
 
 
 def saveAttachments(attachments, path):
@@ -442,11 +448,10 @@ def saveAttachments(attachments, path):
 
 def saveAttachmentsToTempFiles(attachments):
 
-	#save files
-	for attach in attachments:
-		log("saveAttachmentsToTempFiles filename=" + attach[0])
+	for a in attachments:
+		log("saveAttachmentsToTempFiles filename=" + a[0])
 
-		fileName, fileExtension = os.path.splitext(attach[0])
+		fileName, fileExtension = os.path.splitext(a[0])
 
 		## our temp directory
 		tempdir = "/tmp/hubemailattach"
@@ -462,15 +467,16 @@ def saveAttachmentsToTempFiles(attachments):
 		# create a unique temp file
 		fd, filename = tempfile.mkstemp(fileExtension, fileName + "-", tempdir)
 		f = os.fdopen(fd, "w")
-		f.write(attach[1])
+		f.write(a[2])
 		f.close()
 
 		# change temp file owner to www-data
 		os.chmod(filename, 0444)
 		#os.chown(filename, pwd.getpwnam('www-data')[2], -1)
 
-		# Dump the complete temp filename into the attachments array for this entry
-		attach.append(filename)
+		# Dump the complete temp filename into the attachments array for this entry, it will
+		# be a new third list element
+		a.append(filename)
 
 	return 1
 
@@ -525,15 +531,29 @@ def sendEmail(toaddress, subject, messagetext, fromaddress = '', fromname = '',
 	
 	msg.attach(textmsg)
 
-	server = smtplib.SMTP("localhost")
 
-	# Make the envelope's return-path different form the from address used in the email headers.
-	# This helps with bounce processsing, SMTP servers will (usually) send bounces to the
-	# return-path address
-	if envelope_from:
-		server.sendmail(envelope_from, toaddress, msg.as_string())
-	else:
-		server.sendmail(mailfrom_email, toaddress, msg.as_string())
+	# catch SMTPConnectorErrors with code of 421, these get 
+	# thrown by conservatively set SMTP servers and the error is:
+	# 'Too many concurrent SMTP connections from this IP address; please try again later'
+	#
+	# This section will retry until sucessful
+	while True:
+		try:
+			server = smtplib.SMTP("localhost")
+
+			# Make the envelope's return-path different form the from address used in the email headers.
+			# This helps with bounce processsing, SMTP servers will (usually) send bounces to the
+			# return-path address
+			if envelope_from:
+				server.sendmail(envelope_from, toaddress, msg.as_string())
+			else:
+				server.sendmail(mailfrom_email, toaddress, msg.as_string())
+                except smtplib.SMTPConnectError as e:
+                        if e[0] == 421:
+                                time.sleep(random.randrange(2,8))
+                                continue
+		break
+
 
 	server.quit()
 
@@ -643,3 +663,30 @@ def grabComponentParameter(componentName, parameterName):
 			return ""
 	else:
 		return ""
+
+
+def getCurrentTime():
+	# no better way to detect what date version is being used with
+	# a given hub installation: local time or UTC
+
+	# get default site's doc root
+	defaultSite = hubzero.config.hubzerositeconfig.getHubDefaultSite()
+	wwwDocRoot = hubzero.config.hubzerositeconfig.getHubzeroConfigOption(defaultSite, 'documentroot')
+
+	# cms.php file has version info
+	fileName = wwwDocRoot + "/libraries/cms.php"
+	if os.path.isfile(wwwDocRoot + "/libraries/cms.php"):
+
+		f = open(fileName, 'r')
+		fileText =  f.read()
+
+		match = re.search(r"define\(.*'HVERSION'.*,.*1.2.0.*\);",  fileText)
+		if match is not None:
+			return datetime.datetime.now()
+		else:
+			# any value other than 1.2 means use the new format. Earlier than 1.2 didn't have$
+			return datetime.datetime.utcnow()
+	else:
+		# if file doesn't exist we know we're pre 1.2
+		return datetime.datetime.now()
+
