@@ -25,7 +25,6 @@
 #
 # HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
-
 import base64
 import cgi
 import ConfigParser
@@ -119,7 +118,7 @@ try:
 					componentObject.group(1),
 					componentObjectId.group(1),
 					emailbody,
-					datetime.datetime.utcnow()
+					mailproc.getCurrentTime()
 					)
 			
 			# insert record
