@@ -187,10 +187,10 @@ try:
 			sql_values = "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s"
 			data = ("Emailed forum response from " + emailFromAddress,
 				userfeedback + "\n---- Emailed forum response from " + emailFromAddress,
-				datetime.datetime.utcnow(), userid, 1, 0,
+				mailproc.getCurrentTime(), userid, 1, 0,
 				parent, 0, 4,
-				0, datetime.datetime.utcnow(), userid, categoryid,
-				datetime.datetime.utcnow())
+				0, mailproc.getCurrentTime(), userid, categoryid,
+				mailproc.getCurrentTime())
 
 			# add any necessary colums for all the different versions of this table bouncing around out there
 			if scope_field:
