@@ -281,6 +281,44 @@ try:
 					mailproc.mailfrom_name,
 					"htc-" + newtoken  + '@' +  mailproc.hubShortURL)
 
+
+			### send email to any watchers, but check to see if the watcher's table is there, it isn't in every hub
+
+			db = mailproc.db_connect()
+			cursor = db.cursor()
+			sql = "SELECT count(1) FROM information_schema.TABLES WHERE TABLE_NAME = 'jos_support_watching'"
+			cursor.execute(sql)
+			rs = cursor.fetchone()
+
+			# is the jos_support_watching table present
+			if rs[0] == 1:
+				db = mailproc.db_connect()
+				cursor = db.cursor ()
+				sql = "select ju.email, ju.id "
+				sql += "from jos_support_watching w "
+				sql += "join jos_users ju on (ju.id = w.user_id) "
+				sql += "where w.ticket_id = " + str(ticketID)
+
+				cursor.execute(sql)
+
+				for row in cursor.fetchall():
+
+					watcherEmail = row[0]
+					watcherUserID = row[1]
+
+					newtoken = mailproc.createEmailToken('01','01', watcherUserID, ticketid)
+					mailproc.log("Emailing ticket watcher " + watcherEmail)
+
+					mailproc.sendEmail(watcherEmail,
+						subject,
+						message,
+						mailproc.mailfrom_email,
+						mailproc.mailfrom_name,
+						"htc-" + newtoken  + '@' +  mailproc.hubShortURL)
+
+	                        db.close()
+
+
 			# Record what we did for the comment on the ticket
 			changelog = "<ul class=""email-in-log""><li>Comment submitted via email from " + emailFromAddress + "</li></ul>"
 
@@ -313,7 +351,7 @@ try:
 			cursor = db.cursor ()
 			sql  = "INSERT INTO jos_support_comments (ticket, comment, created, created_by, changelog, access) "
 			sql += "VALUES( %s, %s, %s, %s, %s, %s )"
-			data = ( ticketID, emailbody, datetime.datetime.utcnow(), username, changelog, 0)
+			data = ( ticketID, emailbody, mailproc.getCurrentTime(), username, changelog, 0)
 			cursor.execute (sql, data)
 			commentid = cursor.lastrowid
 			mailproc.log("Inserted email ticket comment (" + str(commentid) +  ") into database")
@@ -340,20 +378,19 @@ try:
 				virusDetected = False
 
 				for attach in attachments:
-					mailproc.log("temp attachment filename:" + attach[2])
+					mailproc.log("temp attachment filename:" + attach[3])
 
-					avProc = subprocess.Popen(["clamscan", "-i", "--no-summary" , "--block-encrypted", attach[2]],
+					avProc = subprocess.Popen(["clamscan", "-i", "--no-summary" , "--block-encrypted", attach[3]],
 					                          shell=False,
 					                          stdout=subprocess.PIPE)
 					avProc.wait()
 
 					if avProc.returncode:
-						mailproc.log("Virus detected in attachment " + attach[2] + " - aborting processing of all attachments")
+						mailproc.log("Virus detected in attachment " + attach[3] + " - aborting processing of all attachments")
 						virusDetected = True
 						break
 					else:
-						mailproc.log("clamscan reports clean file for " + attach[2])
-
+						mailproc.log("clamscan reports clean file for " + attach[3])
 				if not virusDetected:
 					mailproc.log("No viruses detected in any attachments")
 
@@ -365,7 +402,7 @@ try:
 
 						# grab the temp filename from the complete path, use the temp filename (it's unique)
 						# to prevent overwriting of multiple files with same name from overwriting each other
-						dname, fname = os.path.split(attach[2])
+						dname, fname = os.path.split(attach[3])
 
 						sql_attach = "INSERT INTO jos_support_attachments(ticket ,filename) VALUES( %s, %s)"
 						attach_data = (ticketid, fname)
@@ -388,7 +425,7 @@ try:
 
 						# grab the temp filename from the complete path, use the temp filename (it's unique)
 						# to prevent overwriting of multiple files with same name from overwriting each other
-						dname, fname = os.path.split(attach[2])
+						dname, fname = os.path.split(attach[3])
 
 						destFileName = str(path + "/" + fname)
 						mailproc.log("Copying ticket attachment to " + destFileName)
@@ -399,7 +436,7 @@ try:
 							                    stdout=subprocess.PIPE,
 							                    stderr=subprocess.PIPE)
 
-						filecopyFileNames = attach[2] + " " + destFileName
+						filecopyFileNames = attach[3] + " " + destFileName
 						pout, perr = fileCopyProc.communicate(filecopyFileNames)
 
 						# deal with any subprocess errors
@@ -412,8 +449,8 @@ try:
 
 					# delete temp files
 					for attach in attachments:
-						mailproc.log("Removing temp file " + attach[2])
-						os.remove(attach[2])
+						mailproc.log("Removing temp file " + attach[3])
+						os.remove(attach[3])
 
 				else:
 					# append info to ticket comment indicating error with attachments
